package com.ruoyi.system.mapper;

import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.ruoyi.system.domain.SocialFeedback;

import java.util.List;

/**
 * 社会反馈Mapper接口
 * 
 * @author ruoyi
 * @date 2025-03-26
 */
public interface SocialFeedbackMapper  extends BaseMapper<SocialFeedback>
{
    /**
     * 查询社会反馈
     * 
     * @param id 社会反馈主键
     * @return 社会反馈
     */
    public SocialFeedback selectSocialFeedbackById(Long id);

    /**
     * 查询社会反馈列表
     * 
     * @param socialFeedback 社会反馈
     * @return 社会反馈集合
     */
    public List<SocialFeedback> selectSocialFeedbackList(SocialFeedback socialFeedback);

    /**
     * 新增社会反馈
     * 
     * @param socialFeedback 社会反馈
     * @return 结果
     */
    public int insertSocialFeedback(SocialFeedback socialFeedback);

    /**
     * 修改社会反馈
     * 
     * @param socialFeedback 社会反馈
     * @return 结果
     */
    public int updateSocialFeedback(SocialFeedback socialFeedback);

    /**
     * 删除社会反馈
     * 
     * @param id 社会反馈主键
     * @return 结果
     */
    public int deleteSocialFeedbackById(Long id);

    /**
     * 批量删除社会反馈
     * 
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteSocialFeedbackByIds(Long[] ids);
}
