package com.ruoyi.app.promotion;

import com.ruoyi.common.annotation.Anonymous;
import com.ruoyi.common.annotation.Log;
import com.ruoyi.common.core.controller.BaseController;
import com.ruoyi.common.core.domain.AjaxResult;
import com.ruoyi.common.core.page.TableDataInfo;
import com.ruoyi.common.enums.BusinessType;
import com.ruoyi.common.utils.poi.ExcelUtil;
import com.ruoyi.system.domain.SocialFeedback;
//import com.ruoyi.system.service.ISocialFeedbackService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.web.bind.annotation.*;

import jakarta.servlet.http.HttpServletResponse;
import java.util.List;

/**
 * 社会反馈Controller
 *
 * @author ruoyi
 * @date 2025-03-26
 */
@RestController
@RequestMapping("/feeds/feedbacks")
public class SocialFeedbackController extends BaseController
{
//    @Autowired
//    private ISocialFeedbackService socialFeedbackService;
//
//
//    /**
//     * 添加社会反馈
//     * @param socialFeedback
//     * @return
//     */
//    @Anonymous
//    @PostMapping("/addFeedback")
//    public AjaxResult addFeedback(@RequestBody SocialFeedback socialFeedback)
//    {
//        return toAjax(socialFeedbackService.insertSocialFeedback(socialFeedback));
//    }
//
//    /**
//     * 反馈列表
//     * @param socialFeedback
//     * @return
//     */
//    @Anonymous
//    @GetMapping("/Feedbacklist")
//    public TableDataInfo Feedbacklist(SocialFeedback socialFeedback)
//    {
//        SocialFeedback social = socialFeedback;
//        social.setAuditStatus("1");
//        startPage();
//        List<SocialFeedback> list = socialFeedbackService.selectSocialFeedbackList(social);
//        return getDataTable(list);
//    }
//
//    /**
//     * 查询社会反馈列表
//     */
//    @PreAuthorize("@ss.hasPermi('feeds:feedbacks:list')")
//    @GetMapping("/list")
//    public TableDataInfo list(SocialFeedback socialFeedback)
//    {
//        startPage();
//        List<SocialFeedback> list = socialFeedbackService.selectSocialFeedbackList(socialFeedback);
//        return getDataTable(list);
//    }
//
//    /**
//     * 导出社会反馈列表
//     */
//    @PreAuthorize("@ss.hasPermi('feeds:feedbacks:export')")
//    @Log(title = "社会反馈", businessType = BusinessType.EXPORT)
//    @PostMapping("/export")
//    public void export(HttpServletResponse response, SocialFeedback socialFeedback)
//    {
//        List<SocialFeedback> list = socialFeedbackService.selectSocialFeedbackList(socialFeedback);
//        ExcelUtil<SocialFeedback> util = new ExcelUtil<SocialFeedback>(SocialFeedback.class);
//        util.exportExcel(response, list, "社会反馈数据");
//    }
//
//    /**
//     * 获取社会反馈详细信息
//     */
//    @PreAuthorize("@ss.hasPermi('feeds:feedbacks:query')")
//    @GetMapping(value = "/{id}")
//    public AjaxResult getInfo(@PathVariable("id") Long id)
//    {
//        return success(socialFeedbackService.selectSocialFeedbackById(id));
//    }
//
//    /**
//     * 新增社会反馈
//     */
//    @PreAuthorize("@ss.hasPermi('feeds:feedbacks:add')")
//    @Log(title = "社会反馈", businessType = BusinessType.INSERT)
//    @PostMapping
//    public AjaxResult add(@RequestBody SocialFeedback socialFeedback)
//    {
//        return toAjax(socialFeedbackService.insertSocialFeedback(socialFeedback));
//    }
//
//    /**
//     * 修改社会反馈
//     */
//    @PreAuthorize("@ss.hasPermi('feeds:feedbacks:edit')")
//    @Log(title = "社会反馈", businessType = BusinessType.UPDATE)
//    @PutMapping
//    public AjaxResult edit(@RequestBody SocialFeedback socialFeedback)
//    {
//        return toAjax(socialFeedbackService.updateSocialFeedback(socialFeedback));
//    }
//
//    /**
//     * 删除社会反馈
//     */
//    @PreAuthorize("@ss.hasPermi('feeds:feedbacks:remove')")
//    @Log(title = "社会反馈", businessType = BusinessType.DELETE)
//	@DeleteMapping("/{ids}")
//    public AjaxResult remove(@PathVariable Long[] ids)
//    {
//        return toAjax(socialFeedbackService.deleteSocialFeedbackByIds(ids));
//    }
}
